# [Title of the ADR]

## Status

[Proposed | Accepted | Deprecated | Superseded by [ADR-NNNN](NNNN-example.md)]

## Context

[Describe the context and problem statement that this decision addresses. What is the issue that we're seeing that is motivating this decision or change?]

## Decision

[Describe the decision that was made, clearly stating what the team has agreed to do.]

## Consequences

[What becomes easier or more difficult to do because of this change? Are there any risks introduced by this decision?]

## Alternatives Considered

[What other options were considered, and why were they not chosen?]
